Engine.RegisterInterface("EndGameManager");

/**
 * Message of the form {}
 * sent from EndGameManager component.
 */
Engine.RegisterMessageType("GameTypeChanged");
